import { notification} from 'antd';
import axios from 'axios';
import cookie from 'react-cookies';

export const TokenKey = 'autologin_trustie';
export default function javaFetch(actionUrl){
  if (window.location.href.indexOf('localhost') < 0) {
    axios.defaults.withCredentials = true;
  }
  
  // 创建axios实例
  const service = axios.create({
    baseURL: actionUrl,
    timeout: 1800000, // 请求超时时间
  });
  
  // request拦截器
service.interceptors.request.use(config => {
  if (cookie.load(TokenKey)) {
    config.headers['Authorization'] = cookie.load(TokenKey) ||cookie.load('autologin_trustie'); // 让每个请求携带自定义token 请根据实际情况自行修改
  }
  if (window.location.port === "3007") {
    // 模拟token为登录用户
    const osredmToken = cookie.load(TokenKey) ||cookie.load('autologin_trustie')||sessionStorage.osredmToken;
    if (config.url.indexOf('?') === -1) {
      config.url = `${config.url}?token=${osredmToken}`;
    } else {
      config.url = `${config.url}&token=${osredmToken}`;
    }
  }
  return config;
}, error => {
  // Do something with request error
  console.log(error); // for debug
  Promise.reject(error);
});
// respone拦截器
service.interceptors.response.use(
  response => {
    const res = response;
    if (res.status === 400) {
      notification.open({
        message: "提示",
        description: res.data.message || '验证失败',
      });
      return Promise.reject('error');
    }
    if (res.status === 401) {
      notification.open({
        message: "提示",
        description: res.data.message || '未授权，请登录！',
      });
      return Promise.reject('error');
    }
    if (res.status === 403) {
      notification.open({
        message: "提示",
        description: res.data.message || '无权限',
      });
      return Promise.reject('error');
    }
    if (res.status === 40001) {
      notification.open({
        message: "提示",
        description: '账户或密码错误！',
      });
      return Promise.reject('error');
    }
    if (!res.status.toString().startsWith('2')) {
      notification.open({
        message: "提示",
        description: res.message,
      });
    } else {
      return response.data;
    }
  },
  error => {
    console.log(error);
    let res = error.response||{};
    if (res.status === 400) {
      notification.open({
        message: "提示",
        description: res.data.message || '操作失败',
      });
      return Promise.reject('error');
    }
    if (res.status === 401) {
      notification.open({
        message: "提示",
        description: res.data.message || '登录信息已过期',
      });
      return Promise.reject('error');
    }
    if (res.status === 403) {
      notification.open({
        message: "提示",
        description: res.data.message || '无权限！',
      });
      if(window.location.port !== "3007"){
        window.location.href="/403";
      }
      return Promise.reject('error');
    }
   
    return Promise.reject(error);
  }
);

  return service;
}